aboutsummaryrefslogtreecommitdiffstats
path: root/services/convert
diff options
context:
space:
mode:
authorLunny Xiao <xiaolunwen@gmail.com>2023-07-10 17:31:19 +0800
committerGitHub <noreply@github.com>2023-07-10 09:31:19 +0000
commit0fd1672ae49a5f69fca7d90336ae75be83a21014 (patch)
tree21b651c5ae3bf4db7434ef44de1ac9b4c7865703 /services/convert
parent5489962aac6faf3260176a0f53cbb78c44c421a5 (diff)
downloadgitea-0fd1672ae49a5f69fca7d90336ae75be83a21014.tar.gz
gitea-0fd1672ae49a5f69fca7d90336ae75be83a21014.zip
For API attachments, use API URL (#25639)
Fix #25257 --------- Co-authored-by: Giteabot <teabot@gitea.io>
Diffstat (limited to 'services/convert')
-rw-r--r--services/convert/activity.go2
-rw-r--r--services/convert/attachment.go40
-rw-r--r--services/convert/issue.go19
-rw-r--r--services/convert/issue_comment.go10
-rw-r--r--services/convert/release.go6
5 files changed, 62 insertions, 15 deletions
diff --git a/services/convert/activity.go b/services/convert/activity.go
index 71a2722a49..01fef73e58 100644
--- a/services/convert/activity.go
+++ b/services/convert/activity.go
@@ -37,7 +37,7 @@ func ToActivity(ctx context.Context, ac *activities_model.Action, doer *user_mod
if ac.Comment != nil {
result.CommentID = ac.CommentID
- result.Comment = ToComment(ctx, ac.Comment)
+ result.Comment = ToAPIComment(ctx, ac.Repo, ac.Comment)
}
return result
diff --git a/services/convert/issue.go b/services/convert/issue.go
index bcb1618e8f..d81840f025 100644
--- a/services/convert/issue.go
+++ b/services/convert/issue.go
@@ -19,11 +19,19 @@ import (
api "code.gitea.io/gitea/modules/structs"
)
+func ToIssue(ctx context.Context, issue *issues_model.Issue) *api.Issue {
+ return toIssue(ctx, issue, WebAssetDownloadURL)
+}
+
// ToAPIIssue converts an Issue to API format
// it assumes some fields assigned with values:
// Required - Poster, Labels,
// Optional - Milestone, Assignee, PullRequest
func ToAPIIssue(ctx context.Context, issue *issues_model.Issue) *api.Issue {
+ return toIssue(ctx, issue, APIAssetDownloadURL)
+}
+
+func toIssue(ctx context.Context, issue *issues_model.Issue, getDownloadURL func(repo *repo_model.Repository, attach *repo_model.Attachment) string) *api.Issue {
if err := issue.LoadLabels(ctx); err != nil {
return &api.Issue{}
}
@@ -40,7 +48,7 @@ func ToAPIIssue(ctx context.Context, issue *issues_model.Issue) *api.Issue {
Poster: ToUser(ctx, issue.Poster, nil),
Title: issue.Title,
Body: issue.Content,
- Attachments: ToAttachments(issue.Attachments),
+ Attachments: toAttachments(issue.Repo, issue.Attachments, getDownloadURL),
Ref: issue.Ref,
State: issue.State(),
IsLocked: issue.IsLocked,
@@ -105,6 +113,15 @@ func ToAPIIssue(ctx context.Context, issue *issues_model.Issue) *api.Issue {
return apiIssue
}
+// ToIssueList converts an IssueList to API format
+func ToIssueList(ctx context.Context, il issues_model.IssueList) []*api.Issue {
+ result := make([]*api.Issue, len(il))
+ for i := range il {
+ result[i] = ToIssue(ctx, il[i])
+ }
+ return result
+}
+
// ToAPIIssueList converts an IssueList to API format
func ToAPIIssueList(ctx context.Context, il issues_model.IssueList) []*api.Issue {
result := make([]*api.Issue, len(il))
diff --git a/services/convert/attachment.go b/services/convert/attachment.go
index ddba181a12..ab36a1c577 100644
--- a/services/convert/attachment.go
+++ b/services/convert/attachment.go
@@ -4,12 +4,38 @@
package convert
import (
+ "strconv"
+
repo_model "code.gitea.io/gitea/models/repo"
+ "code.gitea.io/gitea/modules/setting"
api "code.gitea.io/gitea/modules/structs"
)
-// ToAttachment converts models.Attachment to api.Attachment
-func ToAttachment(a *repo_model.Attachment) *api.Attachment {
+func WebAssetDownloadURL(repo *repo_model.Repository, attach *repo_model.Attachment) string {
+ return attach.DownloadURL()
+}
+
+func APIAssetDownloadURL(repo *repo_model.Repository, attach *repo_model.Attachment) string {
+ if attach.CustomDownloadURL != "" {
+ return attach.CustomDownloadURL
+ }
+
+ // /repos/{owner}/{repo}/releases/{id}/assets/{attachment_id}
+ return setting.AppURL + "api/repos/" + repo.FullName() + "/releases/" + strconv.FormatInt(attach.ReleaseID, 10) + "/assets/" + strconv.FormatInt(attach.ID, 10)
+}
+
+// ToAttachment converts models.Attachment to api.Attachment for API usage
+func ToAttachment(repo *repo_model.Repository, a *repo_model.Attachment) *api.Attachment {
+ return toAttachment(repo, a, WebAssetDownloadURL)
+}
+
+// ToAPIAttachment converts models.Attachment to api.Attachment for API usage
+func ToAPIAttachment(repo *repo_model.Repository, a *repo_model.Attachment) *api.Attachment {
+ return toAttachment(repo, a, APIAssetDownloadURL)
+}
+
+// toAttachment converts models.Attachment to api.Attachment for API usage
+func toAttachment(repo *repo_model.Repository, a *repo_model.Attachment, getDownloadURL func(repo *repo_model.Repository, attach *repo_model.Attachment) string) *api.Attachment {
return &api.Attachment{
ID: a.ID,
Name: a.Name,
@@ -17,14 +43,18 @@ func ToAttachment(a *repo_model.Attachment) *api.Attachment {
DownloadCount: a.DownloadCount,
Size: a.Size,
UUID: a.UUID,
- DownloadURL: a.DownloadURL(),
+ DownloadURL: getDownloadURL(repo, a), // for web request json and api request json, return different download urls
}
}
-func ToAttachments(attachments []*repo_model.Attachment) []*api.Attachment {
+func ToAPIAttachments(repo *repo_model.Repository, attachments []*repo_model.Attachment) []*api.Attachment {
+ return toAttachments(repo, attachments, APIAssetDownloadURL)
+}
+
+func toAttachments(repo *repo_model.Repository, attachments []*repo_model.Attachment, getDownloadURL func(repo *repo_model.Repository, attach *repo_model.Attachment) string) []*api.Attachment {
converted := make([]*api.Attachment, 0, len(attachments))
for _, attachment := range attachments {
- converted = append(converted, ToAttachment(attachment))
+ converted = append(converted, toAttachment(repo, attachment, getDownloadURL))
}
return converted
}
diff --git a/services/convert/issue_comment.go b/services/convert/issue_comment.go
index db48faa69e..b0145c38e6 100644
--- a/services/convert/issue_comment.go
+++ b/services/convert/issue_comment.go
@@ -14,8 +14,8 @@ import (
"code.gitea.io/gitea/modules/util"
)
-// ToComment converts a issues_model.Comment to the api.Comment format
-func ToComment(ctx context.Context, c *issues_model.Comment) *api.Comment {
+// ToAPIComment converts a issues_model.Comment to the api.Comment format for API usage
+func ToAPIComment(ctx context.Context, repo *repo_model.Repository, c *issues_model.Comment) *api.Comment {
return &api.Comment{
ID: c.ID,
Poster: ToUser(ctx, c.Poster, nil),
@@ -23,14 +23,14 @@ func ToComment(ctx context.Context, c *issues_model.Comment) *api.Comment {
IssueURL: c.IssueURL(),
PRURL: c.PRURL(),
Body: c.Content,
- Attachments: ToAttachments(c.Attachments),
+ Attachments: ToAPIAttachments(repo, c.Attachments),
Created: c.CreatedUnix.AsTime(),
Updated: c.UpdatedUnix.AsTime(),
}
}
// ToTimelineComment converts a issues_model.Comment to the api.TimelineComment format
-func ToTimelineComment(ctx context.Context, c *issues_model.Comment, doer *user_model.User) *api.TimelineComment {
+func ToTimelineComment(ctx context.Context, repo *repo_model.Repository, c *issues_model.Comment, doer *user_model.User) *api.TimelineComment {
err := c.LoadMilestone(ctx)
if err != nil {
log.Error("LoadMilestone: %v", err)
@@ -143,7 +143,7 @@ func ToTimelineComment(ctx context.Context, c *issues_model.Comment, doer *user_
log.Error("LoadPoster: %v", err)
return nil
}
- comment.RefComment = ToComment(ctx, com)
+ comment.RefComment = ToAPIComment(ctx, repo, com)
}
if c.Label != nil {
diff --git a/services/convert/release.go b/services/convert/release.go
index ca28aa0d6b..d8aa46d432 100644
--- a/services/convert/release.go
+++ b/services/convert/release.go
@@ -10,8 +10,8 @@ import (
api "code.gitea.io/gitea/modules/structs"
)
-// ToRelease convert a repo_model.Release to api.Release
-func ToRelease(ctx context.Context, r *repo_model.Release) *api.Release {
+// ToAPIRelease convert a repo_model.Release to api.Release
+func ToAPIRelease(ctx context.Context, repo *repo_model.Repository, r *repo_model.Release) *api.Release {
return &api.Release{
ID: r.ID,
TagName: r.TagName,
@@ -27,6 +27,6 @@ func ToRelease(ctx context.Context, r *repo_model.Release) *api.Release {
CreatedAt: r.CreatedUnix.AsTime(),
PublishedAt: r.CreatedUnix.AsTime(),
Publisher: ToUser(ctx, r.Publisher, nil),
- Attachments: ToAttachments(r.Attachments),
+ Attachments: ToAPIAttachments(repo, r.Attachments),
}
}